@@ -23,11 +23,11 @@ class PlanOutOpRandom(base.PlanOutOpSimple):
     salt = self.parameters['salt']
     salty = '%s.%s' % (self.mapper.experiment_salt, salt)
     unit_str = '.'.join(map(str, self.getUnit(appended_unit)))
-    return int(hashlib.sha1(salty + unit_str).hexdigest()[:15], 16)
+    return int(hashlib.sha1('%s.%s' % (salty, unit_str)).hexdigest()[:15], 16)
 
   def getUniform(self, min_val=0.0, max_val=1.0, appended_unit=None):
     zero_to_one = self.getHash(appended_unit)/PlanOutOpRandom.LONG_SCALE
-    return min_val + max_val*zero_to_one
+    return min_val + (max_val-min_val)*zero_to_one
 
 
 class RandomFloat(PlanOutOpRandom):
